@@ -162,7 +162,16 @@ mt_cursor_manager_restore_cursor (gpointer key,
                                   gpointer value,
                                   gpointer data)
 {
-    mt_cursor_manager_set_xcursor (value);
+    Display *dpy;
+    Cursor xcursor;
+
+    dpy = mt_common_get_xdisplay ();
+    xcursor = XcursorLibraryLoadCursor (dpy, key);
+    if (xcursor)
+    {
+        XFixesChangeCursorByName (dpy, xcursor, key);
+        XFreeCursor (dpy, xcursor);
+    }
 }
 
 static MtCursor *
@@ -279,7 +288,10 @@ mt_cursor_manager_get_current_cursor (MtCursorManager *manager)
 {
     g_return_val_if_fail (MT_IS_CURSOR_MANAGER (manager), NULL);
 
-    return g_object_ref (manager->priv->current);
+    if (manager->priv->current)
+        return g_object_ref (manager->priv->current);
+
+    return NULL;
 }
 
 MtCursor *
